@@ -54,23 +54,18 @@ def test_settings_with_defaults():
     assert config.volume_size == 30
 
 
-def test_settings_with_no_defaults():
-    config = RemoteDockerConfigProfile({})
-
-    with pytest.raises(KeyError):
-        config.aws_profile
-
-    with pytest.raises(KeyError):
-        config.aws_region
-
-
-@mock.patch.dict(
-    os.environ, {"AWS_PROFILE": "mock_aws_profile", "AWS_REGION": "mock_aws_region"}
+@mock.patch(
+    "remote_docker_aws.config.RemoteDockerConfigProfile._boto3_session",
+    new_callable=mock.PropertyMock,
 )
-def test_settings_with_env_var_fallback():
+def test_aws_region_uses_boto_session_fallback(mock_session):
+    mock_session.return_value = mock.MagicMock(region_name="session_aws_region")
+
     config = RemoteDockerConfigProfile({})
-    assert config.aws_profile == "mock_aws_profile"
-    assert config.aws_region == "mock_aws_region"
+    assert config.aws_region == "session_aws_region"
+
+    config = RemoteDockerConfigProfile(dict(aws_region="override_aws_region"))
+    assert config.aws_region == "override_aws_region"
 
 
 def test_settings_with_profile():
